summaryrefslogtreecommitdiff
path: root/Examples/FunctionWithParameters/functionwithparameters.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'Examples/FunctionWithParameters/functionwithparameters.cpp')
-rw-r--r--Examples/FunctionWithParameters/functionwithparameters.cpp62
1 files changed, 60 insertions, 2 deletions
diff --git a/Examples/FunctionWithParameters/functionwithparameters.cpp b/Examples/FunctionWithParameters/functionwithparameters.cpp
index 01db0f6..4f70f26 100644
--- a/Examples/FunctionWithParameters/functionwithparameters.cpp
+++ b/Examples/FunctionWithParameters/functionwithparameters.cpp
@@ -6,9 +6,15 @@
*/
/**
- * Libraries used.
+ * Default Cpp libraries
*/
+
+#include <string>
#include <iostream>
+
+/**
+ * Our own library.
+ */
#include <phpcpp.h>
/**
@@ -43,6 +49,42 @@ Php::Value my_with_defined_parameters_function(Php::Parameters &params)
return params[0] + params[1];
}
+/**
+ * This functions receives a reference to a variable. When the variable is altered,
+ * so is the value in the php script.
+ * my_with_defined_parameters_reference_function()
+ * @param Php::Parameters the given parameters
+ */
+void my_with_defined_parameters_reference_function(Php::Parameters &params)
+{
+ params[0] = "I changed!";
+}
+
+/**
+ * my_with_defined_parameters_reference_function()
+ * @param Php::Parameters the given parameters
+ */
+void my_with_defined_array_parameters_function(Php::Parameters &params)
+{
+ for (int i = 0; i < params[0].size(); i++)
+ {
+ cout << "The array: " << params[0][i] << endl;
+ }
+}
+
+/**
+ * my_with_defined_object_parameters_function()
+ * The use of objects is not yet implemented.
+ * @param Php::Parameters the given parameters
+ */
+void my_with_defined_object_parameters_function(Php::Parameters &params)
+{
+ for (unsigned int i = 0; i < params.size(); i++)
+ {
+ cout << params[i] << endl;
+ }
+}
+
// Symbols are exported according to the "C" language
extern "C"
{
@@ -52,14 +94,30 @@ extern "C"
// create extension
static Php::Extension extension("my_function_with_parameters","1.0");
// add function to extension
extension.add("my_with_undefined_parameters_function", my_with_undefined_parameters_function);
+ // add function, with defined numeric parameters, to extension
extension.add("my_with_defined_parameters_function", my_with_defined_parameters_function, {
Php::ByVal("x", Php::numericType),
Php::ByVal("y", Php::numericType)
});
+ // add function, with defined parameter by reference, to extension
+ extension.add("my_with_defined_parameters_reference_function", my_with_defined_parameters_reference_function, {
+ Php::ByRef("string", Php::stringType)
+ });
+
+ // add function, with defined array parameter, to extension
+ extension.add("my_with_defined_array_parameters_function", my_with_defined_array_parameters_function, {
+ Php::ByVal("array", Php::arrayType)
+ });
+
+ // add function, with defined object parameter, to extension
+ extension.add("my_with_defined_object_parameters_function", my_with_defined_object_parameters_function, {
+ Php::ByVal("myClassObjVar", "MyPhpClass")
+ });
+
// return the extension module
return extension.module();
}
@@ -52,14 +94,30 @@ extern "C"
// create extension
static Php::Extension extension("my_function_with_parameters","1.0");
- // add function to extension
+ // add function, with undefined parameters, to extension
extension.add("my_with_undefined_parameters_function", my_with_undefined_parameters_function);